@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Any
 
 from .interface import Interface
 
 
-class IExposureTime(Interface):
+class IExposureTime(Interface, metaclass=ABCMeta):
     """The camera supports exposure times, to be used together with :class:`~pyobs.interfaces.ICamera`."""
-    __module__ = 'pyobs.interfaces'
 
-    def set_exposure_time(self, exposure_time: float, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def set_exposure_time(self, exposure_time: float, **kwargs: Any) -> None:
         """Set the exposure time in seconds.
 
         Args:
@@ -16,23 +19,25 @@ class IExposureTime(Interface):
         Raises:
             ValueError: If exposure time could not be set.
         """
-        raise NotImplementedError
+        ...
 
-    def get_exposure_time(self, **kwargs: Any) -> float:
+    @abstractmethod
+    async def get_exposure_time(self, **kwargs: Any) -> float:
         """Returns the exposure time in seconds.
 
         Returns:
             Exposure time in seconds.
         """
-        raise NotImplementedError
+        ...
 
-    def get_exposure_time_left(self, **kwargs: Any) -> float:
+    @abstractmethod
+    async def get_exposure_time_left(self, **kwargs: Any) -> float:
         """Returns the remaining exposure time on the current exposure in seconds.
 
         Returns:
             Remaining exposure time in seconds.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IExposureTime']
+__all__ = ["IExposureTime"]
